<?php
/**  
* Plugin Name: DealDoktor Schnaeppchen Widget
* Plugin URI: http://www.dealdoktor.de/das-offizielle-dealdoktor-schnaeppchen-widget-fuer-wordpress/
* Description: Presents the newest bargains on Germany's big Bargain Blog as widget in yur sidebar. Choose from various options. 
* Version: 1.0
* Author: DealDoktor
* Author URI: http://www.dealdoktor.de
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*
*  Installation:
*   - extract the archive, and upload the plugin directory to your wp-content/plugins/ folder!
*   - active "DealDoktor Schnaeppchen" in your wordpress admin panel
*   - go to your widgets section under "Design" and drag and drop the widget onto the sidebar
*
* Changelog:
*       2010-06-05: 1.0
*           Initial release
*/

/**
 * Add function to widgets_init that'll load our widget.
 */
add_action( 'widgets_init', 'load_schnaeppchen' );

/**
 * Register our widget.
 * 'SchnaeppchenWidget' is the widget class used below.
 */
function load_schnaeppchen() {
	register_widget( 'SchnaeppchenWidget' );
}

/**
 * Widget class.
  */
class SchnaeppchenWidget extends WP_Widget {

	function SchnaeppchenWidget() {

		/* Widget settings. */
		$widget_ops = array( 'classname' => 'dd-schnaeppchen-widget', 'description' => __('Zeigt die neuesten Schn&auml;ppchen von DealDoktor.de', 'dd-schnaeppchen-widget') );

		/* Widget control settings. */
		$control_ops = array( 'width' => 400, 'height' => 350, 'id_base' => 'dealdoktor-schnaeppchen' );

		/* Create the widget. */
		$this->WP_Widget( 'dealdoktor-schnaeppchen', __('DealDoktor.de Schn&auml;ppchen', 'dd-schnaeppchen-widget'), $widget_ops, $control_ops );
	}

	
	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$name = $instance['name'];
		$showDeals = $instance['showDeals'];
		$showFooter = isset( $instance['showFooter'] ) ? $instance['showFooter'] : false;
		$feed = $instance['whichDeals'];
		$myPosts = array();	
		$linkTitle = $instance['linkTitle'];
		$i = 0;		

		if ($linkTitle) {
			$link1 = "<a target='_blank' href='http://www.dealdoktor.de'>";
			$link2 = "</a>";
		}
		else {
			$link1 = "";
			$link2 = "";
		}

		/* Before widget (defined by themes). */
		echo $before_widget;
		
		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . "<img src='http://www.dealdoktor.de/dealdoktor_small.png' />&nbsp; $link1". $title . "$link2" . $after_title;

		/* Check which deals shall be shown */
		switch ($feed) {
			case 'blog':
				$xml = file_get_contents('http://feeds.feedburner.com/dealdoktor');
				break;
			case 'forum':
				$xml = file_get_contents('http://feeds.feedburner.com/dealdoktor-schnaeppchen-forum-meldungen');
				break;
			case 'both':
				$xml = file_get_contents('http://feeds.feedburner.com/dealdoktor-blog-und-forum-meldungen');
				break;
			default:
				$xml = file_get_contents('http://feeds.feedburner.com/dealdoktor');
		}
			
		/* Get Feedburner Namespace for correct links and output the feeds to the widget content */
		$xmlobj = new SimpleXMLElement($xml);
		$namespaces = $xmlobj->getDocNamespaces();
				
		echo "<ul>";		
		foreach ($xmlobj->channel->item as $item) {	
		$feedburner_namespace = $item->children($namespaces['feedburner']);
			if ($i < $showDeals) {
				echo "<li><a target='_blank' href='".$feedburner_namespace->origLink."'>".$item->title."</a></li>";
                   $i++;
               }
		}
		echo "</ul>";
		
		if ( $showFooter )
			echo "<p style='font-size:xx-small; text-align:right; line-height:10px'><a href='http://www.dealdoktor.de' target='_blank' title='Schn&auml;ppchen-Blog'>DealDoktor.de<br/>Schn&auml;ppchen Blog</a></p>";

		/* After widget (defined by themes). */
		echo $after_widget;
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['linkTitle'] = strip_tags( $new_instance['linkTitle'] );

		/* No need to strip tags for showDeals and showFooter. */
		$instance['whichDeals'] = $new_instance['whichDeals'];
		$instance['showDeals'] = $new_instance['showDeals'];
		$instance['showFooter'] = $new_instance['showFooter'];

		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 */
	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'title' => __('Aktuelle Schn&auml;ppchen', 'dd-schnaeppchen-widget'), 'name' => __('John Doe', 'dd-schnaeppchen-widget'), 'showDeals' => '5', 'linkTitle' => true, 'showFooter' => true, 'whichDeals' => 'blog' );
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('&Uuml;berschrift:', 'hybrid'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" style="width:100%;" />
		</p>

		<!-- Link the title to our blog? Checkbox-->
		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['linkTitle'], on ); ?> id="<?php echo $this->get_field_id( 'linkTitle' ); ?>" name="<?php echo $this->get_field_name( 'linkTitle' ); ?>" /> 
			<label for="<?php echo $this->get_field_id( 'linkTitle' ); ?>"><?php _e('&Uuml;berschrift als Link?', 'dd-schnaeppchen-widget'); ?></label>
		</p>

		<!-- Which Deals shall be shown? Select Box -->
		<p>
			<label for="<?php echo $this->get_field_id( 'whichDeals' ); ?>"><?php _e('Welche Schn&auml;ppchen sollen gezeigt werden?', 'dd-schnaeppchen-widget'); ?></label> 
			<select id="<?php echo $this->get_field_id( 'whichDeals' ); ?>" name="<?php echo $this->get_field_name( 'whichDeals' ); ?>" class="widefat" style="width:100%;">
				<option <?php if ( 'blog' == $instance['whichDeals'] ) echo 'selected="selected"'; ?> value='blog'>Schn&auml;ppchen aus dem Blog</option>
				<option <?php if ( 'forum' == $instance['whichDeals'] ) echo 'selected="selected"'; ?> value='forum'>Schn&auml;ppchen-Meldungen aus dem Forum (Community)</option>
				<option <?php if ( 'both' == $instance['whichDeals'] ) echo 'selected="selected"'; ?> value='both'>Schn&auml;ppchen aus Blog und Forum</option>
			</select>
		</p>			
		
		<!-- How many Deals shall be shown?: Select Box -->
		<p>
			<label for="<?php echo $this->get_field_id( 'showDeals' ); ?>"><?php _e('Wieviele Schn&auml;ppchen sollen angezeigt werden?', 'dd-schnaeppchen-widget'); ?></label> 
			<select id="<?php echo $this->get_field_id( 'showDeals' ); ?>" name="<?php echo $this->get_field_name( 'showDeals' ); ?>">
				<option <?php if ( '1' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>1</option>
				<option <?php if ( '2' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>2</option>
				<option <?php if ( '3' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>3</option>
				<option <?php if ( '4' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>4</option>
				<option <?php if ( '5' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>5</option>
				<option <?php if ( '6' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>6</option>
				<option <?php if ( '7' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>7</option>
				<option <?php if ( '8' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>8</option>
				<option <?php if ( '9' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>9</option>
				<option <?php if ( '10' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>10</option>
				<option <?php if ( '11' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>11</option>
				<option <?php if ( '12' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>12</option>
				<option <?php if ( '13' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>13</option>
				<option <?php if ( '14' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>14</option>
				<option <?php if ( '15' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>15</option>
				<option <?php if ( '16' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>16</option>
				<option <?php if ( '17' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>17</option>
				<option <?php if ( '18' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>18</option>
				<option <?php if ( '19' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>19</option>
				<option <?php if ( '20' == $instance['showDeals'] ) echo 'selected="selected"'; ?>>20</option>
			</select>
		</p>

		<!-- Show Footer? Checkbox -->
		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['showFooter'], on ); ?> id="<?php echo $this->get_field_id( 'showFooter' ); ?>" name="<?php echo $this->get_field_name( 'showFooter' ); ?>" /> 
			<label for="<?php echo $this->get_field_id( 'showFooter' ); ?>"><?php _e('Widget Footer anzeigen?', 'dd-schnaeppchen-widget'); ?></label>
		</p>

	<?php
	}
}

?>